# Examples


## TRMM Python

These modules were returned from the TRMM Python using `python -m pip list`:
```text
Package        Version
-------------- ---------
certifi        2020.12.5
chardet        4.0.0
decorator      4.4.2
idna           2.10
msgpack        1.0.2
pip            20.3.3
psutil         5.8.0
pywin32        300
pywin32-ctypes 0.2.0
requests       2.25.1
setuptools     51.3.3
six            1.15.0
urllib3        1.26.2
validators     0.18.2
wheel          0.36.2
WMI            1.5.1
```


These modules were returned from the TRMM Python using `help('modules')`:

```text
Please wait a moment while I gather a list of all available modules...

__future__          binhex              msgpack             tarfile
_abc                bisect              msilib              telnetlib
_ast                builtins            msvcrt              tempfile
_asyncio            bz2                 multiprocessing     textwrap
_bisect             cProfile            netbios             this
_blake2             calendar            netrc               threading
_bootlocale         certifi             nntplib             time
_bz2                cgi                 nt                  timeit
_codecs             cgitb               ntpath              timer
_codecs_cn          chardet             ntsecuritycon       token
_codecs_hk          chunk               nturl2path          tokenize
_codecs_iso2022     cmath               numbers             trace
_codecs_jp          cmd                 odbc                traceback
_codecs_kr          code                opcode              tracemalloc
_codecs_tw          codecs              operator            tty
_collections        codeop              optparse            types
_collections_abc    collections         os                  typing
_compat_pickle      colorsys            parser              unicodedata
_compression        commctrl            pathlib             unittest
_contextvars        compileall          pdb                 urllib
_csv                concurrent          perfmon             urllib3
_ctypes             configparser        pickle              uu
_datetime           contextlib          pickletools         uuid
_decimal            contextvars         pip                 validators
_distutils_hack     copy                pipes               warnings
_dummy_thread       copyreg             pkg_resources       wave
_elementtree        crypt               pkgutil             weakref
_functools          csv                 platform            webbrowser
_hashlib            ctypes              plistlib            wheel
_heapq              curses              poplib              win2kras
_imp                dataclasses         posixpath           win32api
_io                 datetime            pprint              win32clipboard
_json               dbi                 profile             win32com
_locale             dbm                 pstats              win32con
_lsprof             dde                 psutil              win32console
_lzma               decimal             pty                 win32cred
_markupbase         decorator           py_compile          win32crypt
_md5                difflib             pyclbr              win32cryptcon
_msi                dis                 pydoc               win32ctypes
_multibytecodec     distutils           pydoc_data          win32event
_multiprocessing    doctest             pyexpat             win32evtlog
_opcode             dummy_threading     pythoncom           win32evtlogutil
_operator           easy_install        pywin               win32file
_osx_support        email               pywin32_bootstrap   win32gui
_overlapped         encodings           pywin32_testutil    win32gui_struct
_pickle             enum                pywintypes          win32help
_py_abc             errno               queue               win32inet
_pydecimal          faulthandler        quopri              win32inetcon
_pyio               filecmp             random              win32job
_queue              fileinput           rasutil             win32lz
_random             fnmatch             re                  win32net
_sha1               formatter           regcheck            win32netcon
_sha256             fractions           regutil             win32pdh
_sha3               ftplib              reprlib             win32pdhquery
_sha512             functools           requests            win32pdhutil
_signal             gc                  rlcompleter         win32pipe
_sitebuiltins       genericpath         runpy               win32print
_socket             getopt              sched               win32process
_sqlite3            getpass             secrets             win32profile
_sre                gettext             select              win32ras
_ssl                glob                selectors           win32rcparser
_stat               gzip                servicemanager      win32security
_statistics         hashlib             setuptools          win32service
_string             heapq               shelve              win32serviceutil
_strptime           hmac                shlex               win32timezone
_struct             html                shutil              win32trace
_symtable           http                signal              win32traceutil
_thread             idna                site                win32transaction
_threading_local    imaplib             six                 win32ts
_tracemalloc        imghdr              smtpd               win32ui
_warnings           imp                 smtplib             win32uiole
_weakref            importlib           sndhdr              win32verstamp
_weakrefset         inspect             socket              win32wnet
_win32sysloader     io                  socketserver        winerror
_winapi             ipaddress           sqlite3             winioctlcon
_winxptheme         isapi               sre_compile         winnt
_xxsubinterpreters  itertools           sre_constants       winperf
abc                 json                sre_parse           winreg
adodbapi            keyword             ssl                 winsound
afxres              lib2to3             sspi                winxpgui
aifc                linecache           sspicon             winxptheme
antigravity         locale              stat                wmi
argparse            logging             statistics          wsgiref
array               lzma                string              xdrlib
ast                 mailbox             stringprep          xml
asynchat            mailcap             struct              xmlrpc
asyncio             marshal             subprocess          xxsubtype
asyncore            math                sunau               zipapp
atexit              mimetypes           symbol              zipfile
audioop             mmap                symtable            zipimport
base64              mmapfile            sys                 zlib
bdb                 mmsystem            sysconfig
binascii            modulefinder        tabnanny
```
